@@ -110,7 +110,6 @@ class MeshSendMessageChunkApplication(
 
         is_finished = self.input.get("complete", False)
         if is_finished:
-            # TODO log error
             self.response.update({"statusCode": HTTPStatus.INTERNAL_SERVER_ERROR.value})
             raise SystemError("Already completed upload to MESH")
 
@@ -164,6 +163,10 @@ class MeshSendMessageChunkApplication(
         if self.chunked and not is_finished:
             self.current_chunk += 1
 
+        if is_finished:
+            # check mailbox for any reports
+            _response, _messages = self.mailbox.list_messages()
+
         # update input event to send as response
         self.response.update({"statusCode": status_code})
         self.response["body"].update(
@@ -175,6 +178,8 @@ class MeshSendMessageChunkApplication(
             }
         )
 
+        self.mailbox.clean_up()
+
 
 # create instance of class in global space
 # this ensures initial setup of logging/config is only done on cold start
